Page
Library
Module
Module type
Parameter
Class
Class type
Gg.MSourceImplemented by all (square) matrix types.
The type for matrices.
dim is the dimension of rows and columns.
The type for rows and columns as vectors.
el i j a is the element aij.
Raises Invalid_argument if i or j is not in [0;dim[.
row i a is the ith row of a.
Raises Invalid_argument if i is not in [0;dim[.
col j a is the jth column of a.
Raises Invalid_argument if j is not in [0;dim[.
mul a b is the matrix multiplication a * b.
trace a is the matrix trace trace(a).
det a is the determinant |a|.
inv a is the inverse matrix a-1.
mapi f a is like map but the element indices are also given.
foldi f acc a is f (...(f (f acc 0 0 a00) 1 0 a10)...).
equal_f eq a b tests a and b like equal but uses eq to test floating point values.
compare a b is Stdlib.compare a b. That is lexicographic comparison in column-major order.
compare_f cmp a b compares a and b like compare but uses cmp to compare floating point values.
pp ppf a prints a textual representation of a on ppf.
pp_f pp_e ppf a prints a like pp but uses pp_e to print floating point values.