Page
Library
Module
Module type
Parameter
Class
Class type
Gg.M3Source3D square matrices.
dim is the dimension of rows and columns.
v e00 e01 e02 e10 e11 e12 e20 e21 e22 is a matrix whose components are specified in row-major order
of_rows r0 r1 r2 is the matrix whose rows are r0, r1 and r2.
of_cols c0 c1 c2 is the matrix whose columns are c0, c1 and c2.
el i j a is the element aij. See also the direct element accessors.
Raises Invalid_argument if i or j is not in [0;dim[.
row i a is the ith row of a.
Raises Invalid_argument if i is not in [0;dim[.
col j a is the jth column of a.
Raises Invalid_argument if j is not in [0;dim[.
of_m2_v2 m v is the matrix whose first two rows are those of m,v side by side and the third is 0 0 1.
mul a b is the matrix multiplication a * b.
trace a is the matrix trace trace(a).
det a is the determinant |a|.
inv a is the inverse matrix a-1.
rot2 pt theta rotates 2D space around the point pt by theta radians. pt defaults to P2.o.
rigid2 move theta is the rigid body transformation of 2D space that rotates by theta radians and then translates by move.
srigid2 move theta scale is like rigid2 but starts by scaling according to scale.
rot3_map u v rotates 3D space to map the unit vector u on the unit vector v.
rot_axis v theta rotates 3D space by theta radians around the unit vector v.
rot3_zyx r rotates 3D space first by V3.x r radians around the x-axis, then by V3.y r radians around the y-axis and finally by V3.z r radians around the z-axis.
mapi f a is like map but the element indices are also given.
fold f acc a is f (...(f (f acc a00) a10)...).
foldi f acc a is f (...(f (f acc 0 0 a00) 1 0 a10)...).
equal_f eq a b tests a and b like equal but uses eq to test floating point values.
compare a b is Stdlib.compare a b. That is lexicographic comparison in column-major order.
compare_f cmp a b compares a and b like compare but uses cmp to compare floating point values.
pp ppf a prints a textual representation of a on ppf.
pp_f pp_e ppf a prints a like pp but uses pp_e to print floating point values.