sectionYPositions = computeSectionYPositions($el), 10)"
x-init="setTimeout(() => sectionYPositions = computeSectionYPositions($el), 10)"
>
On This Page
Gg.P3Source3D points.
The type for matrices representing linear transformations of homogenous 3D space.
tr m p is the affine transform in homogenous 3D space of the point p by m.
Note. Since m is supposed to be affine the function ignores the last row of m. p is treated as a finite point (its last coordinate in homogenous space is 1). Use V3.tr to transform vectors (infinite points).