Page
Library
Module
Module type
Parameter
Class
Class type
Gg.VSourceImplemented by all vector types.
The type for vectors.
The type for matrices representing linear transformations of dim space.
comp i v is vi, the ith component of v.
Raises Invalid_argument if i is not in [0;dim[.
basis i is the ith vector of an orthonormal basis of the vector space t with inner product dot.
Raises Invalid_argument if i is not in [0;dim[.
dot u v is the dot product u.v.
homogene v is the vector v/(comp (dim - 1) v) if comp (dim - 1) v <> 0 and v otherwise.
ltr m v is the linear transform mv.
Stdlib operatorsmapi f v is like map but the component index is also given.
foldi f acc v is f (...(f (f acc 0 v0) 1 v1)...).
equal_f eq u v tests u and v like equal but uses eq to test floating point values.
compare_f cmp u v compares u and v like compare but uses cmp to compare floating point values.
pp ppf v prints a textual representation of v on ppf.
pp_f pp_comp ppf v prints v like pp but uses pp_comp to print floating point values.