Page
Library
Module
Module type
Parameter
Class
Class type
Gg.BoxSourceImplemented by all axis-aligned box types.
The type for boxes.
The type for matrices representing linear transformations of dim space.
min b is the smallest point of b (its origin).
Raises Invalid_argument on empty
max b is the greatest point of b (its size added to the origin).
Raises Invalid_argument on empty
inset d b is b whose edges are inset in each dimension according to amounts in d. Negative values in d outset. If the size in dimension i becomes negative it is clamped to 0 and the ith coordinate of the mid point of b is used for the ith coordinate of the resulting box's origin. Returns empty on empty.
is_pt b is true iff b is not empty and its size is equal to 0 in every dimension.
equal_f eq b b' tests b and b' like equal but uses eq to test floating point values.
compare_f cmp b b' compares b and b' like compare but uses cmp to compare floating point values.
pp ppf b prints a textual representation of b on ppf.
pp_f pp_fl ppf b prints b like pp but uses pp_fl to print floating point values.